@@ -237,9 +237,8 @@ void SambaUserSharePlugin::setReady(bool ready)
 
 void SambaUserSharePlugin::reboot()
 {
-    QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"),
-                                QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
-    interface.asyncCall(QStringLiteral("logout"), 0, 1, 2); // Options: do not ask again | reboot | force
+    QDBusInterface kdeShutdown(QStringLiteral("org.kde.Shutdown"), QStringLiteral("/Shutdown"), QStringLiteral("org.kde.Shutdown"));
+    kdeShutdown.call(QStringLiteral("logoutAndReboot"));
 }
 
 #include "sambausershareplugin.moc"
